from setuptools import setup
setup(name = "sLIntell",
version = "1.0.1",
description = "This is a package which can speak and listen to your commands. Developed for personal use only. Copyright to Siddh Rathod",
author = "Siddh Rathod",
author_email = 'siddhrathod1@gmail.com',
license = 'MIT',
keywords = (['speak tool','listen tool']),
packages = (['sLIntell']),
install_requires = (['pyttsx3', 'speechRecognition']),
)